==> nextcloud-15.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/pt_BR.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Informação da CPU não disponível",
    "Load average" : "Carregamento médio",
    "Last minute" : "Último minuto",
    "Memory info not available" : "Informações de memória não disponíveis",
    "Total" : "Total",
    "Current usage" : "Uso atual:",
    "Users" : "Usuários",
    "Groups" : "Grupos",
    "Links" : "Links",
    "Federated sent" : "Envio federado",
    "Federated received" : "Recebimento federado",
    "Last 24 hours" : "Últimas 24 horas",
    "Last 1 hour" : "Última 1 hora",
    "Last 5 mins" : "Últimos 5 minutos",
    "Copy" : "Copiar",
    "Copied!" : "Copiado!",
    "Not supported!" : "Não suportado!",
    "Press ⌘-C to copy." : "Pressione ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Pressione Ctrl-C para copiar.",
    "Monitoring" : "Monitoramento",
    "Monitoring app with useful server information" : "Aplicativo de monitoramento com informações úteis do servidor",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Fornece informações úteis do servidor, como carga de CPU, uso de RAM, uso do disco, número de usuários, etc.",
    "CPU load" : "Carga da CPU",
    "Memory usage" : "Uso de memória",
    "Active users" : "Usuários ativos",
    "Shares" : "Compartilhamentos",
    "Storage" : "Armazenamento",
    "Users:" : "Usuários:",
    "Files:" : "Arquivos:",
    "Storages:" : "Armazenamentos:",
    "Free Space:" : "Espaço Livre:",
    "Nextcloud" : "Nextcloud",
    "Version:" : "Versão:",
    "Apps installed:" : "Aplicativos instalados:",
    "Apps updates available:" : "Atualizações de aplicativos disponíveis:",
    "PHP" : "PHP",
    "Memory Limit:" : "Limite de memória:",
    "Max Execution Time:" : "Tempo máximo de execução:",
    "Upload max size:" : "Tamanho máximo para envio:",
    "Database" : "Banco de Dados",
    "Type:" : "Tipo:",
    "Size:" : "Tamanho:",
    "External monitoring tool" : "Ferramenta de monitoramento externo",
    "You can connect an external monitoring tool by using this end point:" : "Você pode conectar uma ferramenta de monitoramento externa usando este ponto final:",
    "Did you know?" : "Você sabia?",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "Acrescentar \"?format=json\" no final da URL fornece o resultado no formato JSON!",
    "You can connect an external monitoring tool by using this end point: " : "Você pode conectar uma ferramenta de monitoramento externa usando este ponto: "
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/pt_BR.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Informação da CPU não disponível",
    "Load average" : "Carregamento médio",
    "Last minute" : "Último minuto",
    "Memory info not available" : "Informações de memória não disponíveis",
    "Total" : "Total",
    "Current usage" : "Uso atual:",
    "Users" : "Usuários",
    "Groups" : "Grupos",
    "Links" : "Links",
    "Mails" : "E-mails",
    "Federated sent" : "Envio federado",
    "Federated received" : "Recebimento federado",
    "Talk conversations" : "Conversas",
    "24 hours" : "24 horas",
    "1 hour" : "1 hora",
    "5 mins" : "5 mins",
    "Copy" : "Copiar",
    "Copied!" : "Copiado!",
    "Not supported!" : "Não suportado!",
    "Press ⌘-C to copy." : "Pressione ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Pressione Ctrl-C para copiar.",
    "System" : "Sistema",
    "Monitoring" : "Monitoramento",
    "Monitoring app with useful server information" : "Aplicativo de monitoramento com informações úteis do servidor",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Fornece informações úteis do servidor, como carga de CPU, uso de RAM, uso do disco, número de usuários, etc.",
    "Operating System" : "Sistema Operacional",
    "CPU" : "CPU",
    "Memory" : "Memória",
    "Server time" : "Hora do servidor",
    "Uptime" : "Tempo ativo",
    "Time Servers" : "Servidores de Horário",
    "Load" : "Carregar",
    "Disk" : "Disco",
    "Mount" : "Montar",
    "Filesystem" : "Sistema de arquivos",
    "Size" : "Tamanho",
    "Available" : "Disponível",
    "Used" : "Usado",
    "You will get a notification once one of your disks is nearly full." : "Você receberá uma notificação quando um dos seus discos estiver quase cheio.",
    "Files:" : "Arquivos:",
    "Storages:" : "Armazenamentos:",
    "Free Space:" : "Espaço Livre:",
    "Network" : "Rede",
    "Hostname" : "Hostname",
    "DNS" : "DNS",
    "Gateway" : "Gateway",
    "Status" : "Status",
    "Speed" : "Velocidade",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Active users" : "Usuários ativos",
    "Total users:" : "Total de usuários:",
    "Shares" : "Compartilhamentos",
    "PHP" : "PHP",
    "Version:" : "Versão:",
    "Memory Limit:" : "Limite de memória:",
    "Max Execution Time:" : "Tempo máximo de execução:",
    "Upload max size:" : "Tamanho máximo para envio:",
    "Database" : "Banco de Dados",
    "Type:" : "Tipo:",
    "Size:" : "Tamanho:",
    "External monitoring tool" : "Ferramenta de monitoramento externo",
    "You can connect an external monitoring tool by using this end point:" : "Você pode conectar uma ferramenta de monitoramento externa usando este ponto final:",
    "Did you know?" : "Você sabia?",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "Acrescentar \"?format=json\" no final da URL fornece o resultado no formato JSON!",
    "Last 24 hours" : "Últimas 24 horas",
    "Last 1 hour" : "Última 1 hora",
    "Last 5 mins" : "Últimos 5 minutos",
    "CPU load" : "Carga da CPU",
    "Memory usage" : "Uso de memória",
    "Storage" : "Armazenamento",
    "Users:" : "Usuários:",
    "Nextcloud" : "Nextcloud",
    "Apps installed:" : "Aplicativos instalados:",
    "Apps updates available:" : "Atualizações de aplicativos disponíveis:"
},
"nplurals=2; plural=(n > 1);");
